/**
 * Copyright 2008 Bluestem Software LLC
 *   
 * All Rights Reserved. Bluestem Software LLC licenses this file
 * to you under the EOA Specification License Agreement [1]. You
 * may not use this file except in compliance with the License. You
 * may obtain a copy of the License at:
 *   
 * [1] http://alakai.org/licensing/specification-eoa-license.html
 *   
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.bluestemsoftware.specification.eoa;

import org.bluestemsoftware.specification.eoa.AbstractClassLoader;
import org.bluestemsoftware.specification.eoa.system.SystemClassLoader;

/**
 * Identifies a dependency 'provided' by <code>System</code> at runtime, i.e. as opposed to
 * being resolved by <code>DependencyManager</code>. A provided dependency SHOULD be added
 * by <code>System</code> to the 'application' classpath. A provided dependency MUST be
 * visible to parent classloader of all instances of {@link AbstractClassLoader}. Transitive
 * dependencies, i.e. dependencies upon which the referenced artifact depends MUST NOT be
 * processed.
 * <p>
 * The rules used to distinguish a <code>ProvidedDependency</code> from other deployment
 * dependencies are an extension to the core specification.
 * <p>
 * Note that the following provided dependencies, as identified by their versionless refs, MUST
 * be provided by default by a compliant <code>System</code>.
 * <p>
 * org.bluestemsoftware.specification.eoa:specification-eoa
 * <p>
 * Note that the application classpath SHOULD be limited to these artifacts alone, along with a
 * minimal set of interfaces and classes required to 'bootstrap' the <code>System</code>.
 * Additional classes required by <code>System</code> to implement its behavior SHOULD be
 * scoped to the {@link SystemClassLoader}.
 */

public interface ProvidedDependency extends Dependency {
}
