/**
 * Copyright 2008 Bluestem Software LLC
 *   
 * All Rights Reserved. Bluestem Software LLC licenses this file
 * to you under the EOA Specification License Agreement [1]. You
 * may not use this file except in compliance with the License. You
 * may obtain a copy of the License at:
 *   
 * [1] http://alakai.org/licensing/specification-eoa-license.html
 *   
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.bluestemsoftware.specification.eoa;

import org.bluestemsoftware.specification.eoa.SharedClassLoader;

/**
 * Identifies a dependency 'shared' across all deployments and by <code>System</code>. A
 * shared artifact MUST be added by <code>System</code> as a constituent within shared class
 * realm, i.e. visible to {@link SharedClassLoader}.
 * <p>
 * The rules used to distinguish a <code>SharedDependency</code> from other deployment
 * dependencies are an extension to the core specification.
 * <p>
 * Note that when configuring the shared classpath, if a dependency with the same organization
 * id, the same artifact id and a different version as compared to an existing version, is
 * encountered, and the existing version is not 'managed', the latest version MUST be added. If
 * dependency cannot be added, e.g. the artifact could not be resolved the dependent deployment
 * MUST fail to deploy.
 * <p>
 * Note that constituents within shared class realm SHOULD be restricted to 'specification'
 * libraries, i.e. libraries which contain interfaces and abstract classes, e.g. the eoa
 * specification, the javax specifications, etc ... Libraries containing concrete classes, i.e.
 * implemenation classes, SHOULD be scoped to deployment's classloader. Contact the authoring
 * organization, if necessary, and request that they refactor any artifact that violates these
 * guidelines.
 */

public interface SharedDependency extends Dependency {

    /**
     * Indicates if dependecy is 'required.' If not required, dependency MUST NOT be added to
     * shared classpath. It must, however be added to 'project' classpath, i.e. for project
     * compilation.
     * <p>
     * Note that this MAY be necessary to define a dependency which is 'shared' between a
     * runtime <code>Engine</code> component and the <code>Application</code> it
     * implements, i.e. the dependency is scoped to engine deployment which is visible to
     * {@link ApplicationClassloader}.
     * <p>
     * The rule used to distinguish a required 'shared' dependency from a shared dependency
     * that is not required, is an extension to the core specification.
     * 
     * @return true if required, false if not.
     */
    public boolean isRequired();

}
