/**
 * Copyright 2008 Bluestem Software LLC
 *   
 * All Rights Reserved. Bluestem Software LLC licenses this file
 * to you under the EOA Specification License Agreement [1]. You
 * may not use this file except in compliance with the License. You
 * may obtain a copy of the License at:
 *   
 * [1] http://alakai.org/licensing/specification-eoa-license.html
 *   
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.bluestemsoftware.specification.eoa.component;

import org.bluestemsoftware.specification.eoa.DeploymentClassLoader;
import org.bluestemsoftware.specification.eoa.DeploymentContext;
import org.bluestemsoftware.specification.eoa.DeploymentException;

/**
 * Defines context within which a <code>Component</code> is deployed.
 */
public final class ComponentContext extends DeploymentContext {

    private ComponentDeployment deployment;

    public ComponentContext(ComponentDeployment deployment, DeploymentClassLoader classLoader) {
        super(classLoader);
        if (deployment == null) {
            throw new IllegalArgumentException("deployment null");
        } else {
            this.deployment = deployment;
        }
    }

    /**
     * Gets <code>ComponentDeployment</code> with which this context is associated.
     * 
     * @return deployment
     */
    public ComponentDeployment getDeployment() {
        return deployment;
    }
    
    /**
     * Establishes a <code>ComponentReference</code> made by a <code>Component</code> defined
     * within contained deployment.
     * 
     * @param componentReference
     * @return
     * @throws DeploymentException
     */
    public <R extends RootComponent> R findReferencedComponent(ComponentReference<R> componentReference)throws DeploymentException {
        return deployment.findReferencedComponent(componentReference);
    }    
    
}
