/**
 * Copyright 2008 Bluestem Software LLC
 *   
 * All Rights Reserved. Bluestem Software LLC licenses this file
 * to you under the EOA Specification License Agreement [1]. You
 * may not use this file except in compliance with the License. You
 * may obtain a copy of the License at:
 *   
 * [1] http://alakai.org/licensing/specification-eoa-license.html
 *   
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.bluestemsoftware.specification.eoa.component;

import java.util.Collections;
import java.util.List;
import java.util.Map;

import org.bluestemsoftware.specification.eoa.ComponentDependency;
import org.bluestemsoftware.specification.eoa.DeploymentDependencies;
import org.bluestemsoftware.specification.eoa.FeatureDependency;
import org.bluestemsoftware.specification.eoa.OtherDependency;
import org.bluestemsoftware.specification.eoa.ProvidedDependency;
import org.bluestemsoftware.specification.eoa.ScopedDependency;
import org.bluestemsoftware.specification.eoa.SharedDependency;

/**
 * Models dependencies defined by a {@link ComponentDeployment}, i.e. dependencies upon which
 * <code>Component</code> instances defined within deployment MAY depend in order to
 * implement their behavior.
 */
public final class ComponentDependencies extends DeploymentDependencies {

    private List<ComponentDependency> componentDependencies;
    
    public ComponentDependencies() {
        super();
    }

    public ComponentDependencies(List<ProvidedDependency> providedDependencies, List<SharedDependency> sharedDependencies, List<ScopedDependency> scopedDependencies, List<FeatureDependency> featureDependencies,  List<ComponentDependency> componentDependencies, Map<String, OtherDependency> otherDependencies) {
        super(providedDependencies, sharedDependencies, scopedDependencies, featureDependencies, otherDependencies);
        if (componentDependencies != null) {
            this.componentDependencies = Collections.unmodifiableList(componentDependencies);
        }
    }
    
    /**
     * Identifies 'component' dependencies defined by deployment including
     * transitive dependencies.
     * 
     * @return list of 'component' dependencies
     */
    @SuppressWarnings("unchecked")
    public final List<ComponentDependency> getComponentDependencies() {
        if (componentDependencies == null) {
            return Collections.EMPTY_LIST;
        }
        return componentDependencies;
    }
    
    
}
