/**
 * Copyright 2008 Bluestem Software LLC
 *   
 * All Rights Reserved. Bluestem Software LLC licenses this file
 * to you under the EOA Specification License Agreement [1]. You
 * may not use this file except in compliance with the License. You
 * may obtain a copy of the License at:
 *   
 * [1] http://alakai.org/licensing/specification-eoa-license.html
 *   
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.bluestemsoftware.specification.eoa.component;

import org.bluestemsoftware.specification.eoa.component.RootComponent.ComponentName;
import org.bluestemsoftware.specification.eoa.component.RootComponent.ComponentType;
import org.bluestemsoftware.specification.eoa.component.types.Schema;
import org.bluestemsoftware.specification.eoa.component.types.SchemaComponent.Type;

/**
 * A <code>Component</code> that references a <code>RootComponent</code>. Reference is
 * initially in name only, i.e. when parent definition is loaded. Reference to actual
 * <code>RootComponent</code> is 'established' when parent definition is deployed.
 */
public interface ComponentReference<R extends RootComponent> {

    /**
     * Gets <code>FragmentIdentifier</code> of referencing component.
     * @return
     */
    public FragmentIdentifier getFragmentIdentifier();

    /**
     * Returns name of referenced component.
     * @return
     */
    public ComponentName getReferencedComponentName();

    /**
     * Returns type of referenced component.
     * @return
     */
    public ComponentType getReferencedComponentType();

    /**
     * Returns class of referenced component, i.e. which may be required for generics
     * sub-typing.
     * 
     * @return
     */
    public Class<R> getReferencedComponentClass();

    /**
     * Returns referenced <code>Component</code>.
     * 
     * @return ReferencedComponent or <code>null</code> if reference not yet established.
     */
    public R getReferencedComponent();

    /**
     * Indirectly references a <code>Schema</code> by referencing a schema component defined
     * within schema.
     */
    public interface SchemaComponentReference extends ComponentReference<Schema> {

        /**
         * Schema component name.
         * @return
         */
        public String getSchemaComponentName();

        /**
         * Schema component type.
         * @return
         */
        public Type getSchemaComponentType();

    }

    /**
     * Indirectly references a <code>Schema</code> by referencing a schema property defined
     * within schema.
     */
    public interface SchemaPropertyReference extends ComponentReference<Schema> {

        /**
         * Name of referenced schema property.
         * @return
         */
        public String getSchemaPropertyName();

    }

}