/**
 * Copyright 2008 Bluestem Software LLC
 *   
 * All Rights Reserved. Bluestem Software LLC licenses this file
 * to you under the EOA Specification License Agreement [1]. You
 * may not use this file except in compliance with the License. You
 * may obtain a copy of the License at:
 *   
 * [1] http://alakai.org/licensing/specification-eoa-license.html
 *   
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.bluestemsoftware.specification.eoa.component.application.rt;

import org.bluestemsoftware.specification.eoa.component.application.Role;
import org.bluestemsoftware.specification.eoa.component.policy.rt.ElementPolicy;
import org.bluestemsoftware.specification.eoa.component.rt.NestedComponentRT;

/**
 * References a 'partner' <code>Role</code> component.
 */
public interface RoleReference extends NestedComponentRT<ApplicationRT, ApplicationReference> {

       /**
     * Identifies name of <code>Role</code> on referenced partner component.
     * 
     * @return name of referenced <code>Role</code>.
     */
    public String getRoleName();

    /**
     * Gets <code>Role</code> defined on referenced partner component.
     * @return
     */
    public Role getRole();

    /**
     * Gets <code>ElementPolicy</code> attached to this component.
     * 
     * @return elementPolicy or <code>null</code> if no policy attached
     */
    public ElementPolicy getElementPolicy();

}
