/**
 * Copyright 2008 Bluestem Software LLC
 *   
 * All Rights Reserved. Bluestem Software LLC licenses this file
 * to you under the EOA Specification License Agreement [1]. You
 * may not use this file except in compliance with the License. You
 * may obtain a copy of the License at:
 *   
 * [1] http://alakai.org/licensing/specification-eoa-license.html
 *   
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.bluestemsoftware.specification.eoa.component.binding;

import javax.xml.namespace.QName;

import org.bluestemsoftware.specification.eoa.component.FragmentIdentifier;
import org.bluestemsoftware.specification.eoa.component.NestedComponent;
import org.bluestemsoftware.specification.eoa.component.FragmentIdentifier.Scheme;

/**
 * Statically defines 'underlying' protocol employed by a <code>Binding</code> which binds a
 * specific messaging protocol e.g. SOAP to a specific transmission protocol, e.g. HTTP.
 * <p>
 * The rules which define a concrete instance of <code>UnderlyingProtocol</code> are an
 * extension to the core specification.
 */
public abstract class UnderlyingProtocol extends NestedComponent<Binding, Binding> {

    protected String protocolType;

    public UnderlyingProtocol(String protocolType) {
        if (protocolType == null) {
            throw new IllegalArgumentException("protocolType null");
        } else {
            this.protocolType = protocolType;
        }
    }

    /*
     * (non-Javadoc)
     * @see org.bluestemsoftware.specification.eoa.component.Component#getFragmentIdentifier()
     */
    public FragmentIdentifier getFragmentIdentifier() {
        if (fragmentIdentifier == null) {
            QName rootName = getRootComponent().getName();
            StringBuffer pointerPart = new StringBuffer();
            pointerPart.append(rootName.getLocalPart());
            pointerPart.append("/");
            pointerPart.append(protocolType);
            fragmentIdentifier = new FragmentIdentifier(rootName.getNamespaceURI(), Scheme.EOA,
                    "bindingUnderlyingProtocol", pointerPart.toString());
        }
        return fragmentIdentifier;
    }

    /**
     * Returns type ref URI which uniquely identifies <code>UnderlyingProtocol</code> type.
     * 
     * @return
     */
    public String getProtocolType() {
        return protocolType;
    }

    void setParent(Binding parent) {
        this.parent = parent;
    }

}
