/**
 * Copyright 2008 Bluestem Software LLC
 *   
 * All Rights Reserved. Bluestem Software LLC licenses this file
 * to you under the EOA Specification License Agreement [1]. You
 * may not use this file except in compliance with the License. You
 * may obtain a copy of the License at:
 *   
 * [1] http://alakai.org/licensing/specification-eoa-license.html
 *   
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.bluestemsoftware.specification.eoa.component.policy.rt;

import java.util.Set;

/**
 * Models a policy 'alternative', i.e a <code>Set</code> of <code>PolicyAssertion</code>
 * elements. Note that compliant implementations MUST be immutable.
 */
public interface PolicyAlternative extends Set<PolicyAssertion> {

    /**
     * Indicates whether or not alternative is supported. Note that an alternative which
     * contains no assertions is, by definition, supported, i.e. 'no behavior is specified.'
     * 
     * @return true if all assertions defined within alternative are supported, false if not.
     * 
     * @see PolicyAssertion#isSupported()
     */
    public boolean isSupported();

}
