/**
 * Copyright 2008 Bluestem Software LLC
 *   
 * All Rights Reserved. Bluestem Software LLC licenses this file
 * to you under the EOA Specification License Agreement [1]. You
 * may not use this file except in compliance with the License. You
 * may obtain a copy of the License at:
 *   
 * [1] http://alakai.org/licensing/specification-eoa-license.html
 *   
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.bluestemsoftware.specification.eoa.ext;

import java.io.File;

/**
 * Defines behavior for a specific type of <code>ManageableExtension</code>, i.e. one that
 * can be 'executed' via the receipt of message instance(s).
 */
public abstract class ExecutableExtension extends ManageableExtension {

    public interface Provider extends ManageableExtension.Provider {
    }

    public ExecutableExtension(ExtensionFactory factory, Provider provider, File extensionEtcDir, File extensionVarDir) {
        super(factory, provider, extensionEtcDir, extensionVarDir);
    }

    /**
     * Indicates whether or not <code>ExecutableExtension</code> is in a suspended state.
     * <p>
     * Note than an <code>ExecutableExtension</code> MUST be in a suspended state before
     * corresponding <code>RuntimeComponent</code> can be modified, i.e. unloaded.
     * 
     * @return true if suspended, false if not
     */
    public abstract boolean isSuspended();

    /**
     * Suspends the flow of messages.
     * <p>
     * Note than an <code>ExecutableExtension</code> MUST be in a suspended state before
     * corresponding <code>RuntimeComponent</code> can be modified, i.e. unloaded.
     */
    public abstract void suspend() throws ExecutableException;

    /**
     * Resumes the flow of messages.
     */
    public abstract void resume() throws ExecutableException;

}
