/**
 * Copyright 2008 Bluestem Software LLC
 *   
 * All Rights Reserved. Bluestem Software LLC licenses this file
 * to you under the EOA Specification License Agreement [1]. You
 * may not use this file except in compliance with the License. You
 * may obtain a copy of the License at:
 *   
 * [1] http://alakai.org/licensing/specification-eoa-license.html
 *   
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.bluestemsoftware.specification.eoa.ext.engine;

import java.io.File;
import java.net.URI;
import java.net.URISyntaxException;

import org.bluestemsoftware.specification.eoa.component.FragmentIdentifier;
import org.bluestemsoftware.specification.eoa.component.engine.rt.EngineRT;
import org.bluestemsoftware.specification.eoa.component.rt.ProviderReader;
import org.bluestemsoftware.specification.eoa.ext.ExtensionFactory;
import org.bluestemsoftware.specification.eoa.system.SystemContext;

/**
 * A type specific factory for creating <code>Engine</code> components.
 */

public abstract class EngineFactory extends ExtensionFactory implements ProviderReader<EngineRT> {

    /*
     * (non-Javadoc)
     * 
     * SPI
     */
    public interface Provider extends ExtensionFactory.Provider {
    }

    /*
     * (non-Javadoc)
     * @see org.bluestemsoftware.specification.eoa.ext.ExtensionFactory#getType()
     */
    public final Type getType() {
        return Type.ENGINE;
    }
    
    protected File createEngineVarDir(FragmentIdentifier fragmentIdentifier) {
        File systemVarDir = SystemContext.getContext().getSystem().getSystemVarDir();
        File temp = null;
        try {
            temp = toFile(new URI(fragmentIdentifier.toString()));
        } catch (URISyntaxException fatchance) {
        }
        File result = new File(systemVarDir, temp.toString());
        if (!result.exists()) {
            result.mkdir();
        }
        return result;
    }
    
    protected File createEngineEtcDir(FragmentIdentifier fragmentIdentifier) {
        File systemEtcDir = SystemContext.getContext().getSystem().getSystemEtcDir();
        File temp = null;
        try {
            temp = toFile(new URI(fragmentIdentifier.toString()));
        } catch (URISyntaxException fatchance) {
        }
        File result = new File(systemEtcDir, temp.toString());
        if (!result.exists()) {
            result.mkdir();
        }
        return result;
    }

    private File toFile(URI uri) {
        String location = uri.getScheme() == null ? "" : uri.getScheme();
        location = uri.getHost() == null ? location : location + '.' + uri.getHost();
        location = uri.getPort() < 0 ? location : location + '.' + uri.getPort();
        location = uri.getPath() == null ? location : location + uri.getPath();
        location = uri.getFragment() == null ? location : location + '.' + uri.getFragment();
        location = location.replaceAll("/", ".");
        location = location.replaceAll("\\\\", ".");
        location = location.replaceAll(":", ".");
        location = location.replaceAll("\\*", ".");
        location = location.replaceAll("\\?", ".");
        location = location.replaceAll("\"", ".");
        location = location.replaceAll("<", ".");
        location = location.replaceAll(">", ".");
        location = location.replaceAll("\\|", ".");
        location = location.replaceAll("\\(", ".");
        location = location.replaceAll("\\)", ".");
        location = location.endsWith(".") ? location.substring(0, location.length() - 1) : location;
        return new File(location);
    }

}