/**
 * Copyright 2008 Bluestem Software LLC
 *   
 * All Rights Reserved. Bluestem Software LLC licenses this file
 * to you under the EOA Specification License Agreement [1]. You
 * may not use this file except in compliance with the License. You
 * may obtain a copy of the License at:
 *   
 * [1] http://alakai.org/licensing/specification-eoa-license.html
 *   
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.bluestemsoftware.specification.eoa.ext.feature;

import java.io.File;

import org.bluestemsoftware.specification.eoa.FeatureDependency;
import org.bluestemsoftware.specification.eoa.ext.ExtensionFactory;
import org.bluestemsoftware.specification.eoa.system.SystemContext;
import org.bluestemsoftware.specification.eoa.system.server.Feature;

/**
 * A type specific, implementation specific {@link Feature} component factory.
 */

public abstract class FeatureFactory extends ExtensionFactory {

    /*
     * (non-Javadoc)
     * 
     * SPI
     */
    public interface Provider extends ExtensionFactory.Provider {

        public abstract String spi_getFeatureImpl();

    }

    /*
     * (non-Javadoc)
     * 
     * @see org.bluestemsoftware.specification.eoa.ext.ExtensionFactory#getType()
     */
    public final Type getType() {
        return Type.FEATURE;
    }

    /**
     * Returns URI which uniquely identifies <code>Feature</code> implementation within context
     * of <code>Feature</code> type.
     * <p>
     * Value MUST match URI used to identify feature as a dependency, i.e.
     * {@link FeatureDependency#getFeatureImplementationRef()}.
     * 
     * @return
     */
    public String getFeatureImpl() {
        if (factoryContext == null) {
            throw new IllegalStateException("Factory has no context.");
        }
        Thread thread = Thread.currentThread();
        ClassLoader cl = thread.getContextClassLoader();
        try {
            thread.setContextClassLoader(factoryContext.getClassLoader());
            return ((Provider)provider).spi_getFeatureImpl();
        } finally {
            thread.setContextClassLoader(cl);
        }
    }

    /**
     * Creates a type specific instance of {@link Feature}. Invoked by <code>Server</code> when
     * <code>Server</code> is started.
     * 
     * @return Feature
     */
    public abstract Feature createFeature() throws FeatureException;

    protected File createFeatureVarDir() {
        String organizationID = getFactoryContext().getDeployment().getOrganizationID();
        String artifactID =  getFactoryContext().getDeployment().getArtifactID();
        String deploymentRef = organizationID + "." + artifactID;
        File systemVarDir = SystemContext.getContext().getSystem().getSystemVarDir();
        File featureVarDir = new File(systemVarDir, deploymentRef);
        if (!featureVarDir.exists()) {
            featureVarDir.mkdir();
        }
        return featureVarDir;
    }

    protected File createFeatureEtcDir() {
        String organizationID = getFactoryContext().getDeployment().getOrganizationID();
        String artifactID =  getFactoryContext().getDeployment().getArtifactID();
        String deploymentRef = organizationID + "." + artifactID;
        File systemEtcDir = SystemContext.getContext().getSystem().getSystemEtcDir();
        File featureEtcDir = new File(systemEtcDir, deploymentRef);
        if (!featureEtcDir.exists()) {
            featureEtcDir.mkdir();
        }
        return featureEtcDir;
    }

}