/**
 * Copyright 2008 Bluestem Software LLC
 *   
 * All Rights Reserved. Bluestem Software LLC licenses this file
 * to you under the EOA Specification License Agreement [1]. You
 * may not use this file except in compliance with the License. You
 * may obtain a copy of the License at:
 *   
 * [1] http://alakai.org/licensing/specification-eoa-license.html
 *   
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.bluestemsoftware.specification.eoa.ext.feature.ws.transport.rt;

import javax.xml.namespace.QName;

import org.bluestemsoftware.specification.eoa.component.binding.rt.BindingFaultRT;
import org.bluestemsoftware.specification.eoa.component.engine.rt.EndpointReference;
import org.bluestemsoftware.specification.eoa.component.intrface.rt.ActionContext;
import org.bluestemsoftware.specification.eoa.component.message.rt.Content;

/**
 * Encapulates a transport related error which occurred when transporting a message out of
 * 'binding layer'.
 * 
 * @see EndpointReference#sendAction(ActionContext)
 */
public class TransportFault extends BindingFaultRT {

    private static final long serialVersionUID = 1L;

    public static final String ACTION = "http://bluestemsoftware.org/specification/eoa/ext/transport/fault";

    /**
     * An indication that a communication related error occurred, e.g. a dropped connection,
     * etc .... The error MAY be transient in nature.
     */
    public static final QName TRANSPORT_ERROR = new QName(
            "http://bluestemsoftware.org/specification/eoa/ext/transport", "RecoverableError");

    /**
     * An indication that rules which define transport were violated. Request SHOULD NOT be
     * re-sent.
     */
    public static final QName PROTOCOL_ERROR = new QName(
            "http://bluestemsoftware.org/specification/eoa/ext/transport", "UnrecoverableError");

    public TransportFault(QName faultName, String faultReason) {
        super(faultName, faultReason);
    }
    
    public TransportFault(QName faultName, String faultReason, Throwable th) {
        super(faultName, faultReason);
    }

    /*
     * (non-Javadoc)
     * @see org.bluestemsoftware.specification.eoa.component.binding.rt.BindingFault#getAction()
     */
    @Override
    public final String getAction() {
        return ACTION;
    }

    /*
     * (non-Javadoc)
     * @see org.bluestemsoftware.specification.eoa.component.binding.rt.BindingFaultRT#appendFaultDetail(org.bluestemsoftware.specification.eoa.component.message.rt.Content)
     */
    @Override
    public void appendFaultDetail(Content faultEnvelope) {
    }

}
