/**
 * Copyright 2008 Bluestem Software LLC
 *   
 * All Rights Reserved. Bluestem Software LLC licenses this file
 * to you under the EOA Specification License Agreement [1]. You
 * may not use this file except in compliance with the License. You
 * may obtain a copy of the License at:
 *   
 * [1] http://alakai.org/licensing/specification-eoa-license.html
 *   
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.bluestemsoftware.specification.eoa.ext.idl;

import java.util.Set;

import org.bluestemsoftware.specification.eoa.ext.RootExtension;
import org.w3c.dom.Document;

/**
 * Models an IDL (interface definition language) document instance, e.g. a WSDL document, a
 * WADL document, etc ... from/to which <code>RootComponent</code> definitions are
 * read/written.
 * <p>
 * Note that it is implementation's responsibility to switch thread context classloader as
 * required to/from {@link IDLFactory} deployment classloader.
 */
public interface IDLDocument extends RootExtension, Document {

    /*
     * (non-Javadoc)
     * 
     * SPI
     */
    public interface Provider extends RootExtension.Provider {
    }

    /**
     * Gets "target" namespace of <code>IDLDocument</code> which defines namespace of
     * components/resources defined within document. The means by which a document defines the
     * "target" namespace is extension specific.
     * 
     * @return String
     */
    public String getTargetNamespace();

    /**
     * Finds namespace declaration and returns prefix to which it is mapped. If namespace not
     * declared, auto-generates a prefix, e.g. ns01, ns02, ns03, etc ..., and declares it.
     * 
     * @return mapped prefix
     */
    public String addNamespace(String ns);

    /**
     * Returns grammar documents which contain type definitions referenced by
     * components/resources defined within the <code>IDLDocument</code>.
     * <p>
     * Note that if a grammar document is referenced using IDL specific syntax, e.g. via an
     * import or include element defined within the IDL specification's namespace, the document
     * MUST be dereferenced and returned.
     * 
     * @return A <code>Set</code> of documents or an empty set if none defined.
     */
    public Set<Document> getGrammarDocuments();

}
