/**
 * Copyright 2008 Bluestem Software LLC
 *   
 * All Rights Reserved. Bluestem Software LLC licenses this file
 * to you under the EOA Specification License Agreement [1]. You
 * may not use this file except in compliance with the License. You
 * may obtain a copy of the License at:
 *   
 * [1] http://alakai.org/licensing/specification-eoa-license.html
 *   
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.bluestemsoftware.specification.eoa.ext.management;

import java.io.File;

import org.bluestemsoftware.specification.eoa.ext.ExtensionFactory;
import org.bluestemsoftware.specification.eoa.ext.ManageableExtension;
import org.bluestemsoftware.specification.eoa.system.ManagementContext;
import org.bluestemsoftware.specification.eoa.system.SystemContext;

/**
 * An extension factory used by <code>System</code> to create <code>ManagmentContext</code>
 * objects which may then be cast by <code>ManageableExtensions</code> to a well-known type,
 * e.g. Portal Context, JMX Context, etc ..., to facilitate extension management.
 * 
 * @see ManageableExtension#init(ManagementContext)
 * 
 * */

public abstract class ManagementContextFactory extends ExtensionFactory {

    /*
     * (non-Javadoc)
     * 
     * SPI
     */
    public interface Provider extends ExtensionFactory.Provider {
    }

    /*
     * (non-Javadoc)
     * 
     * @see org.bluestemsoftware.specification.eoa.ext.ExtensionFactory#getType()
     */
    public final Type getType() {
        return Type.MANAGEMENT;
    }

    /**
     * Creates a <code>ManagementContext</code> instance.
     * @return
     * @throws ManagementException
     */
    public abstract ManagementContext createManagementContext() throws ManagementException;

    protected File createContextVarDir() {
        String organizationID = getFactoryContext().getDeployment().getOrganizationID();
        String artifactID =  getFactoryContext().getDeployment().getArtifactID();
        String deploymentRef = organizationID + "." + artifactID;
        File systemVarDir = SystemContext.getContext().getSystem().getSystemVarDir();
        File contextVarDir = new File(systemVarDir, deploymentRef);
        if (!contextVarDir.exists()) {
            contextVarDir.mkdir();
        }
        return contextVarDir;
    }

    protected File createContextEtcDir() {
        String organizationID = getFactoryContext().getDeployment().getOrganizationID();
        String artifactID =  getFactoryContext().getDeployment().getArtifactID();
        String deploymentRef = organizationID + "." + artifactID;
        File systemEtcDir = SystemContext.getContext().getSystem().getSystemEtcDir();
        File contextEtcDir = new File(systemEtcDir, deploymentRef);
        if (!contextEtcDir.exists()) {
            contextEtcDir.mkdir();
        }
        return contextEtcDir;
    }
    
}