/**
 * Copyright 2008 Bluestem Software LLC
 *   
 * All Rights Reserved. Bluestem Software LLC licenses this file
 * to you under the EOA Specification License Agreement [1]. You
 * may not use this file except in compliance with the License. You
 * may obtain a copy of the License at:
 *   
 * [1] http://alakai.org/licensing/specification-eoa-license.html
 *   
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.bluestemsoftware.specification.eoa.system;


public abstract class SystemContext {

    protected static SystemContext systemContext;

    /**
     * Returns singleton subclassed and instantiated by <code>System</code> when system is
     * run.
     * 
     * @return SystemContext
     */
    public static SystemContext getContext() {
        if (systemContext == null) {
            throw new IllegalStateException("System has no context.");
        }
        return systemContext;
    }

    /**
     * Gets <code>System</code> component.
     * 
     * @return System
     */
    public abstract org.bluestemsoftware.specification.eoa.system.System getSystem();
    
    /**
     * Gets classloader which loads classes required to implement <code>System</code>
     * behavior, i.e. which effectively hides <code>System</code> implementation from
     * deployments.
     * 
     * @return
     */
    public abstract SystemClassLoader getSystemClassLoader();


}
