/**
 * Copyright 2008 Bluestem Software LLC
 *   
 * All Rights Reserved. Bluestem Software LLC licenses this file
 * to you under the EOA Specification License Agreement [1]. You
 * may not use this file except in compliance with the License. You
 * may obtain a copy of the License at:
 *   
 * [1] http://alakai.org/licensing/specification-eoa-license.html
 *   
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.bluestemsoftware.specification.eoa.system.container;

import org.bluestemsoftware.specification.eoa.ext.Extension;
import org.bluestemsoftware.specification.eoa.ext.RootExtension;
import org.bluestemsoftware.specification.eoa.ext.RootExtension.AbstractRootExtension;
import org.bluestemsoftware.specification.eoa.ext.connector.ConnectorFactory;

/**
 * A <code>Connector</code> component is used to create connections to a resource manager,
 * e.g. a DB server, a JMS server, an EIS, etc ... This component is essentially a proxy for a
 * specific type of <code>javax.resource.spi.ManagedConnectionFactory</code>.
 * <p>
 * <code>Connector</code> components are type specific. Type specific methods may be invoked
 * by casting <code>Connector</code> to a well-known type as indicated by
 * {@link Extension#getExtensionType()}, e.g. a <code>javax.sql.DataSource</code>,
 * <code>javax.jms.ConnectionFactory</code>, etc ...
 * <p>
 * Instances of <code>Connector</code> are threadsafe and MAY be used concurrently. The type
 * specific connection objects returned by a <code>Connector</code>, however, are NOT
 * threadsafe.
 * 
 * @see ConnectorFactory
 */
public abstract class Connector extends AbstractRootExtension {

    protected String connectorName;

    /*
     * (non-Javadoc)
     * 
     * SPI
     */
    public interface Provider extends RootExtension.Provider {
    }

    public Connector(ConnectorFactory factory, Provider provider, String connectorName) {
        super(factory, provider);
        if (connectorName == null) {
            throw new IllegalArgumentException("connectorName null");
        } else {
            this.connectorName = connectorName;
        }
    }

    /**
     * Returns <code>Connector</code> connectorName, which MUST be unique within context of
     * <code>Server</code>.
     * 
     * @return String
     */
    public String getConnectorName() {
        return connectorName;
    }
    
}
