/**
 * Copyright 2008 Bluestem Software LLC
 *   
 * All Rights Reserved. Bluestem Software LLC licenses this file
 * to you under the EOA Specification License Agreement [1]. You
 * may not use this file except in compliance with the License. You
 * may obtain a copy of the License at:
 *   
 * [1] http://alakai.org/licensing/specification-eoa-license.html
 *   
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.bluestemsoftware.specification.eoa.system.container;

import java.io.File;
import java.util.Collection;

import org.bluestemsoftware.specification.eoa.ext.ExtensionFactory;
import org.bluestemsoftware.specification.eoa.ext.ManageableExtension;

/**
 * Models an extensible JCA 'container' as implemented by <code>System</code>. Provides
 * <code>extensions</code> deployed within context of system with connection and transaction
 * support.
 * <p>
 * TODO: bind UserTransaction to 'java:comp/UserTransaction' once directory server feature is
 * implemented.
 * 
 * @see System#getContainer()
 */
public abstract class Container extends ManageableExtension {

    /*
     * (non-Javadoc)
     * 
     * SPI
     */
    public interface Provider extends ManageableExtension.Provider {
    }

    public Container(ExtensionFactory factory, Provider provider, File extensionEtcDir, File extensionVarDir) {
        super(factory, provider, extensionEtcDir, extensionVarDir);
    }

    /**
     * Returns a <code>Connector</code> used to 'connect' to a resource manager, i.e. a db
     * server, a jms server, an EIS, etc ...
     * @param name
     *        which MUST be unique within context of <code>Container</code>.
     * 
     * TODO: bind connectors within 'java:comp/env' namespace once directory server feature is
     * implemented.
     * 
     * @return Connector
     */
    public abstract Connector getConnector(String name);

    /**
     * Returns all <code>Connector</code> components defined within this container.
     * 
     * @return Set of Connector components or an empty set if none defined.
     */
    public abstract Collection<Connector> getConnectors();

    /**
     * Convenience method which retrieves 'system' datasource ,i.e. the connector named
     * {@link DataSourceConnector#SYSTEM_DATA_SOURCE}.
     * 
     * TODO: bind system datasource to 'java:comp/jdbc/SystemDataSource' once directory server
     * feature is implemented.
     * 
     * @return DataSourceConnector or <code>null</code> if undefined.
     */
    public abstract Connector getSystemDataSource();

}
