/**
 * Copyright 2008 Bluestem Software LLC
 *   
 * All Rights Reserved. Bluestem Software LLC licenses this file
 * to you under the EOA Specification License Agreement [1]. You
 * may not use this file except in compliance with the License. You
 * may obtain a copy of the License at:
 *   
 * [1] http://alakai.org/licensing/specification-eoa-license.html
 *   
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.bluestemsoftware.specification.wsa;

import java.io.Serializable;
import java.util.Collections;
import java.util.Set;

import org.w3c.dom.Element;

public class EndpointReference implements Serializable {

    private static final long serialVersionUID = 1L;
    protected String address;
    protected Set<Element> referenceParameters;

    public EndpointReference(String address) {
        this.address = address;
    }

    public EndpointReference(String address, Set<Element> referenceParameters) {
        this.address = address;
        this.referenceParameters = referenceParameters;
    }

    public String getAddress() {
        return address;
    }

    /**
     * Gets reference parameters.
     * @return Refeference parameters or an empty <code>Set</code> if none defined.
     */
    @SuppressWarnings("unchecked")
    public Set<Element> getReferenceParameters() {
        if (referenceParameters == null) {
            return Collections.EMPTY_SET;
        }
        return referenceParameters;
    }
    
}